@@ -12,10 +12,9 @@ import pyperclip
 import inspect
 import json
 import keyring
-from .clevergui import start_gui, button_menu, text_input, sg_options
+from .clevergui import start_gui, button_menu, text_input
 from .cleverutils import to_json, timer
-import .login_to
-import .collect
+from .cleverwebutils import Login_to
 
 class CleverSession(CleverDict):
     """
@@ -96,18 +95,26 @@ class CleverSession(CleverDict):
             keyring.set_password(CleverSession.choices[self.url], self.username, value)
 
     def delete_password(self):
-        """ Delete password from keyring """
+        """
+        Delete password AND username from keyring.
+        .username remains in memory but .password was only ever an @property.
+        """
         keyring.delete_password(CleverSession.choices[self.url], self.username)
 
     @timer
-    def login_with_webbrowser(self):
+    def login_with_webbrowser(self, **kwargs):
+        """
+        KWARGS:
+
+        wait : Seconds for selenium to implicitly_wait
+        """
         self.check_and_prompt("url", "username", "password")
         self.browser = webdriver.Chrome()
-        self.browser.implicitly_wait(3)
+        self.browser.implicitly_wait(kwargs.get("wait") or 3)
         self.browser.get(self.url)
-        dispatch = {"github.com": login_to.github,
-                    "twitter.com": login_to.twitter,
-                    "satchelone.com": login_to.satchelone}
+        dispatch = {"github.com": Login_to.github,
+                    "twitter.com": Login_to.twitter,
+                    "satchelone.com": Login_to.satchelone}
         for website, func in dispatch.items():
             if website in self.url:
                 func(self)
